diff --git a/isis/scripts/isis3VarInit.py b/isis/scripts/isis3VarInit.py
index ec6431691f..122d23f0ae 100755
--- a/isis/scripts/isis3VarInit.py
+++ b/isis/scripts/isis3VarInit.py
@@ -1,14 +1,24 @@
#!/usr/bin/env python
+
import argparse
import os
import sys
-#Author: Tyler Wilson
-#Date : 2018-10-05
-#Description: This script sets ISISROOT/ISIS3DATA/ISIS3TESTDATA for the user and is executed
-#within the conda environment created for the ISIS3 installation.
-#The data directory and test directory are optional command line arguments. If the user chooses
-#not to set them, they will both be placed created on the same level as the $ISISROOT directory
-#within the conda environment.
+
+##########################################################################################################
+# Author: Tyler Wilson
+# Date : 2018-10-05
+# Description: This script sets ISISROOT/ISIS3DATA/ISIS3TESTDATA for the user and is executed
+# within the conda environment created for the ISIS3 installation.
+# The data directory and test directory are optional command line arguments. If the user chooses
+# not to set them, they will both be placed created on the same level as the $ISISROOT directory
+# within the conda environment.
+# History:
+# Author: Tyler Wilson
+# Date: 2018-11-01
+# Description: Removed a pair of lines which were causing output errors on Mac OS X and were not
+# required anyway.
+#
+##########################################################################################################
parser = argparse.ArgumentParser(description='Usage: ./isis3VarInit --data_dir --test_dir
- chmod +x Anaconda3-5.2.0-Linux-x86_64.sh
- ./Anaconda3-5.2.0-Linux-x86_64.sh
+ chmod +x Anaconda3-5.2.0-Linux-x86_64.sh
+ ./Anaconda3-5.2.0-Linux-x86_64.sh
+
This will start the Anaconda installer which will guide you through the installation process.
- #Add the following channels to the Anaconda installation
- conda config --add channels conda-forge, usgs-astrogeology
-
+ #Add the following channels to the Anaconda installation
+ conda config --add channels conda-forge
+ conda config --add channels usgs-astrogeology
+
+ #Verify you have the correct channels:
+ conda config --show channels
+
+ #You should see:
+
+ channels:
+ - usgs-astrogeology
+ - conda-forge
+ - defaults
+
+ #The order is important. If conda-forge is before usgs-astrogeology, you will need to run:
+
+ conda config --add channels usgs-astrogeology
+
- #Create a new conda environment to install ISIS3 in
- conda create -n isis3
+ #Create a new conda environment to install ISIS3 in.
+ conda create -n isis3
- #Activate the environment
- source activate isis3
+ #Activate the environment
+ source activate isis3
- #Download the ISIS3 version
- conda install -c usgs-astrogeology isis3
+ #Download the ISIS3 version
+ conda install -c usgs-astrogeology isis3
- #Execute the ISIS3 variable initialization script with default arguments.
- #This script prepares default values for: $ISISROOT/$ISIS3DATA/$ISIS3TESTDATA
+ #Execute the ISIS3 variable initialization script with default arguments.
+ #This script prepares default values for: $ISISROOT/$ISIS3DATA/$ISIS3TESTDATA
- python $CONDA_PREFIX/scripts/isis3VarInit.py
+ python $CONDA_PREFIX/scripts/isis3VarInit.py
Executing this script with no arguments will result in $ISIS3DATA=$CONDA_PREFIX/data,
and $ISIS3TESTDATA=$CONDA_PREFIX/testdata. The user can specify different directories
for both of these optional values:
- ./$CONDA_PREFIX/scripts/isis3VarInit --data-dir=[path to data directory] --test-dir=[path to test data directory]
+ ./$CONDA_PREFIX/scripts/isis3VarInit --data-dir=[path to data directory] --test-dir=[path to test data directory]
+
+ Directions for running rsync to download ISIS3 data can be found here.
+
+
+ #Run the source activate command a second time to process the changes:
+
+ source activate isis3
+
+ To avoid having to do this every time you open a new terminal window, we suggest adding the following lines to the end of your .bashrc file
+ (if running a variant of Linux) to ensure that conda is in your PATH variable. If you are running Mac OS X, these lines would be appended
+ to the end of your .bash_profile file:
+
+
+ source activate isis3
+ python $CONDA_PREFIX/scripts/isis3VarInit.py
+ source activate isis3
- #Run the source activate command a second time to process the changes:
- source activate isis3
@@ -494,6 +525,7 @@ is a popular choice and may be downloaded below.